@@ -45,7 +45,7 @@ class APIRequestor:
                 headers=rheaders,
             )
         except KeyError:
-            return error.UnknownError
+            return error.UnknownError(body=resp, status_code=rcode)
 
     def interpret_response(self, rbody, rcode, rheaders):
         try:
